@@ -189,17 +189,27 @@ class RfTestCase:
             rf_test_cases.append(rf_test_case)
         return rf_test_cases
 
+    def _create_cbv_parameters(self, interaction: AtomicInteractionCall) -> List[str]:
+        parameters = []
+        for name, value in interaction.cbv_parameters.items():
+            if name.endswith('='):
+                parameters.append(f"{name}{value}")
+            else:
+                parameters.append(value)
+        return parameters
+
     def _create_rf_keyword(self, interaction: AtomicInteractionCall) -> KeywordCall:
         import_prefix = self.config.fullyQualified * f"{interaction.import_prefix}."
         interaction_indent = (
             SEPERATOR * interaction.indent if self.config.logCompoundInteractions else SEPERATOR
         )
+        cbv_parameters = self._create_cbv_parameters(interaction)
         return KeywordCall.from_params(
             assign=tuple(interaction.cbr_parameters.values()),
             name=f"{import_prefix}{interaction.name}",
             args=tuple(
-                interaction.cbv_parameters.values()
-            ),  # TODO  prio later key=value als named erlauben config?
+                cbv_parameters
+            ),  
             indent=interaction_indent,
         )
 
